==> ejc-zdsstore-impl-3.0.0-20240201.031945-156-sources.jar: com/ejianc/business/zdsstore/service/impl/AllotInServiceImpl.java <==
package com.ejianc.business.zdsstore.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.procost.api.ICostDetailApi;
import com.ejianc.business.zdsstore.bean.AllotOutDetailEntity;
import com.ejianc.business.zdsstore.bean.AllotOutEntity;
import com.ejianc.business.zdsstore.consts.AllocatEnum;
import com.ejianc.business.zdsstore.consts.AllocationState;
import com.ejianc.business.zdsstore.consts.InOutTypeEnum;
import com.ejianc.business.zdsstore.service.IAllotOutService;
import com.ejianc.business.zdsstore.service.StoreManageService;
import com.ejianc.business.zdsstore.vo.AllotInExportVO;
import com.ejianc.business.zdsstore.vo.AllotInVO;
import com.ejianc.business.zdsstore.vo.StoreManageVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.time.DateFormatUtil;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.zdsstore.mapper.AllotInMapper;
import com.ejianc.business.zdsstore.bean.AllotInEntity;
import com.ejianc.business.zdsstore.service.IAllotInService;

import javax.servlet.http.HttpServletResponse;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 调拨入库
 *
 * @author generator
 */
@Service("allotInService")
public class AllotInServiceImpl extends BaseServiceImpl<AllotInMapper, AllotInEntity> implements IAllotInService {
    @Autowired
    private IAllotInService service;
    @Autowired
    private IBillTypeApi billTypeApi;

    @Autowired
    private IAllotOutService allotOutService;

    @Autowired
    StoreManageService storeManageService;
    @Autowired
    private IOrgApi iOrgApi;
    private Logger logger = LoggerFactory.getLogger(this.getClass());
    @Autowired
    private ICostDetailApi costDetailApi;
    @Override
    public CommonResponse<String> sureToReceive(AllotInVO vo) {
        AllotInEntity entity = service.selectById(vo.getId());
        if (entity == null) {
            return CommonResponse.error("没有找到该单据！");
        }
        LambdaUpdateWrapper<AllotInEntity> allotinWrapper = new LambdaUpdateWrapper<>();
        allotinWrapper.eq(AllotInEntity::getId, vo.getId());
        allotinWrapper.set(AllotInEntity::getReceiveDate, vo.getReceiveDate());
        allotinWrapper.set(AllotInEntity::getBillState, BillStateEnum.COMMITED_STATE.getBillStateCode());
        allotinWrapper.set(AllotInEntity::getReceiveState, Integer.parseInt(AllocationState.RECEIVED.getCode()));
        allotinWrapper.set(AllotInEntity::getPassDate, vo.getPassDate());
        allotinWrapper.set(AllotInEntity::getReceiverPersonId, vo.getReceiverPersonId());
        allotinWrapper.set(AllotInEntity::getReceiverPerson, vo.getReceiverPerson());
        boolean b = service.update(allotinWrapper);
        //生成调拨入库
        AllotInEntity allot = service.selectById(vo.getId());
        if (CollectionUtils.isNotEmpty(allot.getAllotInDetailList())){
            AllotInVO allotInVO = BeanMapper.map(allot, AllotInVO.class);
            List<StoreManageVO> storeManageVOList = vo.getStoreManageVOList(allotInVO);
            for (StoreManageVO manageVO:storeManageVOList){
                storeManageService.inOutStore(manageVO);
            }        }

        //会写调拨出库
        if (b) {
            LambdaUpdateWrapper<AllotOutEntity> wrapper = new LambdaUpdateWrapper<>();
            wrapper.eq(AllotOutEntity::getId, entity.getAllotOutId());
            wrapper.set(AllotOutEntity::getReceiveState, Integer.parseInt(AllocationState.RECEIVED.getCode()));
            wrapper.set(AllotOutEntity::getReceiverPersonId, vo.getReceiverPersonId());
            wrapper.set(AllotOutEntity::getReceiverPerson, vo.getReceiverPerson());
            wrapper.set(AllotOutEntity::getReceiveDate, vo.getReceiveDate());
            allotOutService.update(wrapper);
        }
        return CommonResponse.success("确认收料成功！");
    }

    @Override
    public CommonResponse<String> sureToReceive(AllotInEntity allotInEntity) {
        allotInEntity.setReceiveDate(new Date());
        allotInEntity.setReceiveState(Integer.parseInt(AllocationState.RECEIVED.getCode()));
        allotInEntity.setPassDate(new Date());
        allotInEntity.setReceiverPersonId(allotInEntity.getEmployeeId().toString());
        allotInEntity.setReceiverPerson(allotInEntity.getEmployeeName());
        service.saveOrUpdate(allotInEntity);
        if (CollectionUtils.isNotEmpty(allotInEntity.getAllotInDetailList())){
            AllotInVO allotInVO = BeanMapper.map(allotInEntity, AllotInVO.class);
            List<StoreManageVO> storeManageVOList = new AllotInVO().getStoreManageVOList(allotInVO);
            for (StoreManageVO manageVO:storeManageVOList){
                storeManageService.inOutStore(manageVO);
            }
        }
        LambdaUpdateWrapper<AllotOutEntity> wrapper = new LambdaUpdateWrapper<>();
        wrapper.eq(AllotOutEntity::getId, allotInEntity.getAllotOutId());
        wrapper.set(AllotOutEntity::getReceiveState, Integer.parseInt(AllocationState.RECEIVED.getCode()));
        wrapper.set(AllotOutEntity::getReceiverPersonId, allotInEntity.getReceiverPersonId());
        wrapper.set(AllotOutEntity::getReceiverPerson, allotInEntity.getReceiverPerson());
        wrapper.set(AllotOutEntity::getReceiveDate, allotInEntity.getReceiveDate());
        allotOutService.update(wrapper);
        return CommonResponse.success("确认收料成功！");
    }

    @Override
    public CommonResponse<String> sureToReturn(AllotInVO vo) {
        AllotInEntity entity = service.selectById(vo.getId());
        if (entity == null) {
            return CommonResponse.error("没有找到该单据！");
        }
        /**
         * 引用校验主要用 调拨出库】被归集单引用后，应不能弃审、撤回
         * 加在修改入库单状态之前和 出库业务逆向处理之前
         */
        AllotOutEntity allotOut = allotOutService.selectById(entity.getAllotOutId());
        CommonResponse<String> commonResponse = billTypeApi.checkQuote("EJCBT202312000014", allotOut.getId());
        boolean success = commonResponse.isSuccess();
        if (!success)
        {
            return CommonResponse.error("调拨出库已经被归集单使用不能弃审和撤回");
        }
        LambdaUpdateWrapper<AllotInEntity> wrapper = new LambdaUpdateWrapper<>();
        wrapper.eq(AllotInEntity::getId, entity.getId());
        wrapper.set(AllotInEntity::getBillState, BillStateEnum.COMMITED_STATE.getBillStateCode());
        wrapper.set(AllotInEntity::getReceiveState, Integer.parseInt(AllocationState.REJECT.getCode()));
        wrapper.set(AllotInEntity::getReceiveDate, vo.getReceiveDate());
        wrapper.set(AllotInEntity::getReceiverPersonId, vo.getReceiverPersonId());
        wrapper.set(AllotInEntity::getReceiverPerson, vo.getReceiverPerson());
        wrapper.set(AllotInEntity::getReturnReason, vo.getReturnReason());

        boolean update = service.update(wrapper);
        if (update) {

            AllotOutEntity allotOutEntity = allotOutService.selectById(entity.getAllotOutId());
            if (allotOutEntity != null) {
                StoreManageVO storeManageVO = new StoreManageVO();
                storeManageVO.setStoreId(allotOutEntity.getId());
                storeManageVO.setSourceId(allotOutEntity.getId());
                storeManageVO.setInOutTypeEnum(InOutTypeEnum.调拨出库);
                storeManageVO.setOutEffectiveON(true);
                ArrayList<Long> longs = new ArrayList<>();
                longs.add(allotOutEntity.getId());
                storeManageVO.setSourceIdsForRollBack(longs);
                storeManageService.inOutStoreRollback(storeManageVO);
            }
            //会写调拨出库 设置为自由态
            LambdaUpdateWrapper<AllotOutEntity> allotOutWrapper = new LambdaUpdateWrapper<>();
            allotOutWrapper.eq(AllotOutEntity::getId, entity.getAllotOutId());
            allotOutWrapper.set(AllotOutEntity::getReceiveState, Integer.parseInt(AllocationState.REJECT.getCode()));
            allotOutWrapper.set(AllotOutEntity::getBillState, BillStateEnum.UNCOMMITED_STATE.getBillStateCode());
            allotOutWrapper.set(AllotOutEntity::getReturnReason, vo.getReturnReason());
            allotOutWrapper.set(AllotOutEntity::getReceiverPersonId, vo.getReceiverPersonId());
            allotOutWrapper.set(AllotOutEntity::getReceiverPerson, vo.getReceiverPerson());
            //调拨出库弃审
            allotOutWrapper.set(AllotOutEntity::getRelationFlag, 0);//(1:是，0：否)
            allotOutService.update(allotOutWrapper);
        }
        return CommonResponse.success("确认收料成功！");
    }

    @Override
    public void excelExport(QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("projectName");
        fuzzyFields.add("storeName");
        fuzzyFields.add("materialNames");
        fuzzyFields.add("outProjectName");
        fuzzyFields.add("employeeName");
        fuzzyFields.add("receiverPerson");
        fuzzyFields.add("billCode");
        fuzzyFields.add("companyName");
        fuzzyFields.add("inCompanyName");
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<AllotInEntity> list = service.queryList(param);
        List<AllotInExportVO> allotInVos = BeanMapper.mapList(list, AllotInExportVO.class);
        allotInVos.forEach(vo->{
            if (vo.getOutDate()!=null){
                vo.setAllocatDate(DateFormatUtil.formatDate("yyyy-MM-dd",vo.getOutDate()));
            }
            if (vo.getReceiveDate()!=null){
                vo.setAllocatReceiveDate(DateFormatUtil.formatDate("yyyy-MM-dd",vo.getReceiveDate()));
            }
            if (vo.getPassDate()!=null){
                vo.setAllocatPassDate(DateFormatUtil.formatDate("yyyy-MM-dd",vo.getPassDate()));
            }
            vo.setBillStateName(BillStateEnum.getEnumByStateCode(vo.getBillState()).getDescription());
            if(vo.getReceiveState()!=null){
                if (Integer.valueOf(AllocationState.TO_RECEIVING.getCode()).equals(vo.getReceiveState())){
                    vo.setReceiveStateName(AllocationState.TO_RECEIVING.getDescription());
                }
                else if (Integer.valueOf(AllocationState.RECEIVED.getCode()).equals(vo.getReceiveState())){
                    vo.setReceiveStateName(AllocationState.RECEIVED.getDescription());
                }
                else if (Integer.valueOf(AllocationState.REJECT.getCode()).equals(vo.getReceiveState())){
                    vo.setReceiveStateName(AllocationState.REJECT.getDescription());
                }
            }
            if (vo.getAllocatType()!=null){
                if (Integer.valueOf(AllocatEnum.ASSETS.getCode()).equals(vo.getAllocatType())){
                    vo.setAllocatTypeName(AllocatEnum.ASSETS.getDescription());
                }
                else {
                    vo.setAllocatTypeName(AllocatEnum.HOMEMADE.getDescription());
                }
            }
        });

        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", allotInVos);
        ExcelExport.getInstance().export("allocationInExport.xlsx", beans, response);
    }
}

==> ejc-zdsstore-impl-3.0.0-20240327.071752-179-sources.jar: com/ejianc/business/zdsstore/service/impl/AllotInServiceImpl.java <==
package com.ejianc.business.zdsstore.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.procost.api.ICostDetailApi;
import com.ejianc.business.zdsstore.bean.AllotOutDetailEntity;
import com.ejianc.business.zdsstore.bean.AllotOutEntity;
import com.ejianc.business.zdsstore.consts.AllocatEnum;
import com.ejianc.business.zdsstore.consts.AllocationState;
import com.ejianc.business.zdsstore.consts.InOutTypeEnum;
import com.ejianc.business.zdsstore.service.IAllotOutService;
import com.ejianc.business.zdsstore.service.StoreManageService;
import com.ejianc.business.zdsstore.vo.AllotInExportVO;
import com.ejianc.business.zdsstore.vo.AllotInVO;
import com.ejianc.business.zdsstore.vo.StoreManageVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.time.DateFormatUtil;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.zdsstore.mapper.AllotInMapper;
import com.ejianc.business.zdsstore.bean.AllotInEntity;
import com.ejianc.business.zdsstore.service.IAllotInService;

import javax.servlet.http.HttpServletResponse;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 调拨入库
 *
 * @author generator
 */
@Service("allotInService")
public class AllotInServiceImpl extends BaseServiceImpl<AllotInMapper, AllotInEntity> implements IAllotInService {
    @Autowired
    private IAllotInService service;
    @Autowired
    private IBillTypeApi billTypeApi;

    @Autowired
    private IAllotOutService allotOutService;

    @Autowired
    StoreManageService storeManageService;
    @Autowired
    private IOrgApi iOrgApi;
    private Logger logger = LoggerFactory.getLogger(this.getClass());
    @Autowired
    private ICostDetailApi costDetailApi;
    @Override
    public CommonResponse<String> sureToReceive(AllotInVO vo) {
        AllotInEntity entity = service.selectById(vo.getId());
        if (entity == null) {
            return CommonResponse.error("没有找到该单据！");
        }
        LambdaUpdateWrapper<AllotInEntity> allotinWrapper = new LambdaUpdateWrapper<>();
        allotinWrapper.eq(AllotInEntity::getId, vo.getId());
        allotinWrapper.set(AllotInEntity::getReceiveDate, vo.getReceiveDate());
        allotinWrapper.set(AllotInEntity::getBillState, BillStateEnum.COMMITED_STATE.getBillStateCode());
        allotinWrapper.set(AllotInEntity::getReceiveState, Integer.parseInt(AllocationState.RECEIVED.getCode()));
        allotinWrapper.set(AllotInEntity::getPassDate, vo.getPassDate());
        allotinWrapper.set(AllotInEntity::getReceiverPersonId, vo.getReceiverPersonId());
        allotinWrapper.set(AllotInEntity::getReceiverPerson, vo.getReceiverPerson());
        boolean b = service.update(allotinWrapper);
        //生成调拨入库
        AllotInEntity allot = service.selectById(vo.getId());
        if (CollectionUtils.isNotEmpty(allot.getAllotInDetailList())){
            AllotInVO allotInVO = BeanMapper.map(allot, AllotInVO.class);
            List<StoreManageVO> storeManageVOList = vo.getStoreManageVOList(allotInVO);
            for (StoreManageVO manageVO:storeManageVOList){
                storeManageService.inOutStore(manageVO);
            }        }

        //会写调拨出库
        if (b) {
            LambdaUpdateWrapper<AllotOutEntity> wrapper = new LambdaUpdateWrapper<>();
            wrapper.eq(AllotOutEntity::getId, entity.getAllotOutId());
            wrapper.set(AllotOutEntity::getReceiveState, Integer.parseInt(AllocationState.RECEIVED.getCode()));
            wrapper.set(AllotOutEntity::getReceiverPersonId, vo.getReceiverPersonId());
            wrapper.set(AllotOutEntity::getReceiverPerson, vo.getReceiverPerson());
            wrapper.set(AllotOutEntity::getReceiveDate, vo.getReceiveDate());
            allotOutService.update(wrapper);
        }
        return CommonResponse.success("确认收料成功！");
    }

    @Override
    public CommonResponse<String> sureToReceive(AllotInEntity allotInEntity) {
        allotInEntity.setReceiveDate(new Date());
        allotInEntity.setReceiveState(Integer.parseInt(AllocationState.RECEIVED.getCode()));
        allotInEntity.setPassDate(new Date());
        allotInEntity.setReceiverPersonId(allotInEntity.getEmployeeId().toString());
        allotInEntity.setReceiverPerson(allotInEntity.getEmployeeName());
        service.saveOrUpdate(allotInEntity);
        if (CollectionUtils.isNotEmpty(allotInEntity.getAllotInDetailList())){
            AllotInVO allotInVO = BeanMapper.map(allotInEntity, AllotInVO.class);
            List<StoreManageVO> storeManageVOList = new AllotInVO().getStoreManageVOList(allotInVO);
            for (StoreManageVO manageVO:storeManageVOList){
                storeManageService.inOutStore(manageVO);
            }
        }
        LambdaUpdateWrapper<AllotOutEntity> wrapper = new LambdaUpdateWrapper<>();
        wrapper.eq(AllotOutEntity::getId, allotInEntity.getAllotOutId());
        wrapper.set(AllotOutEntity::getReceiveState, Integer.parseInt(AllocationState.RECEIVED.getCode()));
        wrapper.set(AllotOutEntity::getReceiverPersonId, allotInEntity.getReceiverPersonId());
        wrapper.set(AllotOutEntity::getReceiverPerson, allotInEntity.getReceiverPerson());
        wrapper.set(AllotOutEntity::getReceiveDate, allotInEntity.getReceiveDate());
        allotOutService.update(wrapper);
        return CommonResponse.success("确认收料成功！");
    }

    @Override
    public CommonResponse<String> sureToReturn(AllotInVO vo) {
        AllotInEntity entity = service.selectById(vo.getId());
        if (entity == null) {
            return CommonResponse.error("没有找到该单据！");
        }
        /**
         * 引用校验主要用 调拨出库】被归集单引用后，应不能弃审、撤回
         * 加在修改入库单状态之前和 出库业务逆向处理之前
         */
        AllotOutEntity allotOut = allotOutService.selectById(entity.getAllotOutId());
        CommonResponse<String> commonResponse = billTypeApi.checkQuote("EJCBT202312000014", allotOut.getId());
        boolean success = commonResponse.isSuccess();
        if (!success)
        {
            return CommonResponse.error("调拨出库已经被归集单使用不能弃审和撤回");
        }
        LambdaUpdateWrapper<AllotInEntity> wrapper = new LambdaUpdateWrapper<>();
        wrapper.eq(AllotInEntity::getId, entity.getId());
        wrapper.set(AllotInEntity::getBillState, BillStateEnum.COMMITED_STATE.getBillStateCode());
        wrapper.set(AllotInEntity::getReceiveState, Integer.parseInt(AllocationState.REJECT.getCode()));
        wrapper.set(AllotInEntity::getReceiveDate, vo.getReceiveDate());
        wrapper.set(AllotInEntity::getReceiverPersonId, vo.getReceiverPersonId());
        wrapper.set(AllotInEntity::getReceiverPerson, vo.getReceiverPerson());
        wrapper.set(AllotInEntity::getReturnReason, vo.getReturnReason());

        boolean update = service.update(wrapper);
        if (update) {
            if (allotOut != null) {
                StoreManageVO storeManageVO = new StoreManageVO();
                storeManageVO.setStoreId(allotOut.getId());
                storeManageVO.setSourceId(allotOut.getId());
                storeManageVO.setInOutTypeEnum(InOutTypeEnum.调拨出库);
                storeManageVO.setOutEffectiveON(true);
                ArrayList<Long> longs = new ArrayList<>();
                longs.add(allotOut.getId());
                storeManageVO.setSourceIdsForRollBack(longs);
                logger.info("退回id:{}",JSONObject.toJSONString(longs));
                storeManageService.inOutStoreRollback(storeManageVO);
            }
            //会写调拨出库 设置为自由态
            LambdaUpdateWrapper<AllotOutEntity> allotOutWrapper = new LambdaUpdateWrapper<>();
            allotOutWrapper.eq(AllotOutEntity::getId, entity.getAllotOutId());
            allotOutWrapper.set(AllotOutEntity::getReceiveState, Integer.parseInt(AllocationState.REJECT.getCode()));
            allotOutWrapper.set(AllotOutEntity::getBillState, BillStateEnum.UNCOMMITED_STATE.getBillStateCode());
            allotOutWrapper.set(AllotOutEntity::getReturnReason, vo.getReturnReason());
            allotOutWrapper.set(AllotOutEntity::getReceiverPersonId, vo.getReceiverPersonId());
            allotOutWrapper.set(AllotOutEntity::getReceiverPerson, vo.getReceiverPerson());
            //调拨出库弃审
            allotOutWrapper.set(AllotOutEntity::getRelationFlag, 0);//(1:是，0：否)
            allotOutService.update(allotOutWrapper);
        }
        return CommonResponse.success("退回成功！");
    }

    @Override
    public void excelExport(QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("projectName");
        fuzzyFields.add("storeName");
        fuzzyFields.add("materialNames");
        fuzzyFields.add("outProjectName");
        fuzzyFields.add("employeeName");
        fuzzyFields.add("receiverPerson");
        fuzzyFields.add("billCode");
        fuzzyFields.add("companyName");
        fuzzyFields.add("inCompanyName");
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<AllotInEntity> list = service.queryList(param);
        List<AllotInExportVO> allotInVos = BeanMapper.mapList(list, AllotInExportVO.class);
        allotInVos.forEach(vo->{
            if (vo.getOutDate()!=null){
                vo.setAllocatDate(DateFormatUtil.formatDate("yyyy-MM-dd",vo.getOutDate()));
            }
            if (vo.getReceiveDate()!=null){
                vo.setAllocatReceiveDate(DateFormatUtil.formatDate("yyyy-MM-dd",vo.getReceiveDate()));
            }
            if (vo.getPassDate()!=null){
                vo.setAllocatPassDate(DateFormatUtil.formatDate("yyyy-MM-dd",vo.getPassDate()));
            }
            vo.setBillStateName(BillStateEnum.getEnumByStateCode(vo.getBillState()).getDescription());
            if(vo.getReceiveState()!=null){
                if (Integer.valueOf(AllocationState.TO_RECEIVING.getCode()).equals(vo.getReceiveState())){
                    vo.setReceiveStateName(AllocationState.TO_RECEIVING.getDescription());
                }
                else if (Integer.valueOf(AllocationState.RECEIVED.getCode()).equals(vo.getReceiveState())){
                    vo.setReceiveStateName(AllocationState.RECEIVED.getDescription());
                }
                else if (Integer.valueOf(AllocationState.REJECT.getCode()).equals(vo.getReceiveState())){
                    vo.setReceiveStateName(AllocationState.REJECT.getDescription());
                }
            }
            if (vo.getAllocatType()!=null){
                if (Integer.valueOf(AllocatEnum.ASSETS.getCode()).equals(vo.getAllocatType())){
                    vo.setAllocatTypeName(AllocatEnum.ASSETS.getDescription());
                }
                else {
                    vo.setAllocatTypeName(AllocatEnum.HOMEMADE.getDescription());
                }
            }
        });

        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", allotInVos);
        ExcelExport.getInstance().export("allocationInExport.xlsx", beans, response);
    }
}
